@@ -330,7 +330,7 @@ class UnicodeChecker(checkers.BaseRawFileChecker):
                 "For compatibility use UTF-8 instead of UTF-16/UTF-32. "
                 "See also https://bugs.python.org/issue1503789 for a history "
                 "of this issue. And "
-                "https://softwareengineering.stackexchange.com/questions/102205/should-utf-16-be-considered-harmful "
+                "https://softwareengineering.stackexchange.com/questions/102205/ "
                 "for some possible problems when using UTF-16 for instance."
             ),
         ),
@@ -347,7 +347,8 @@ class UnicodeChecker(checkers.BaseRawFileChecker):
                 "So can you trust this code? "
                 "Are you sure it displayed correctly in all editors? "
                 "If you did not write it or your language is not RTL,"
-                " remove the special characters, as they could be used to trick you into executing code, "
+                " remove the special characters, as they could be used to trick you into "
+                "executing code, "
                 "that does something else than what it looks like.\n"
                 "More Information:\n"
                 "https://en.wikipedia.org/wiki/Bidirectional_text\n"
@@ -524,7 +525,7 @@ class UnicodeChecker(checkers.BaseRawFileChecker):
             stream.seek(0)
 
             # Check for invalid content (controls/chars)
-            for (lineno, line) in enumerate(
+            for lineno, line in enumerate(
                 _fix_utf16_32_line_stream(stream, codec), start=1
             ):
                 if lineno == 1:
