@@ -17,7 +17,7 @@ from collections import deque
 from collections.abc import Iterable, Iterator
 from functools import lru_cache, partial
 from re import Match
-from typing import TYPE_CHECKING, Callable, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, TypeVar
 
 import _string
 import astroid.objects
@@ -28,6 +28,8 @@ from astroid.nodes._base_nodes import ImportNode
 from astroid.typing import InferenceResult, SuccessfulInferenceResult
 
 if TYPE_CHECKING:
+    from functools import _lru_cache_wrapper
+
     from pylint.checkers import BaseChecker
 
 _NodeT = TypeVar("_NodeT", bound=nodes.NodeNG)
@@ -1848,6 +1850,11 @@ def is_typing_guard(node: nodes.If) -> bool:
     >>> if TYPE_CHECKING:
     >>>     from xyz import a
     """
+    warnings.warn(
+        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )  # pragma: no cover
     return isinstance(
         node.test, (nodes.Name, nodes.Attribute)
     ) and node.test.as_string().endswith("TYPE_CHECKING")
@@ -1855,6 +1862,11 @@ def is_typing_guard(node: nodes.If) -> bool:
 
 def is_node_in_typing_guarded_import_block(node: nodes.NodeNG) -> bool:
     """Return True if node is part for guarded `typing.TYPE_CHECKING` if block."""
+    warnings.warn(
+        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )  # pragma: no cover
     return isinstance(node.parent, nodes.If) and is_typing_guard(node.parent)
 
 
@@ -1863,6 +1875,11 @@ def is_node_in_guarded_import_block(node: nodes.NodeNG) -> bool:
 
     I.e. `sys.version_info` or `typing.TYPE_CHECKING`
     """
+    warnings.warn(
+        "This method will be removed in pylint 3.0; use in_type_checking_block() instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )  # pragma: no cover
     return isinstance(node.parent, nodes.If) and (
         is_sys_guard(node.parent) or is_typing_guard(node.parent)
     )
@@ -1968,7 +1985,10 @@ def in_type_checking_block(node: nodes.NodeNG) -> bool:
         if isinstance(ancestor.test, nodes.Name):
             if ancestor.test.name != "TYPE_CHECKING":
                 continue
-            maybe_import_from = ancestor.test.lookup(ancestor.test.name)[1][0]
+            lookup_result = ancestor.test.lookup(ancestor.test.name)[1]
+            if not lookup_result:
+                return False
+            maybe_import_from = lookup_result[0]
             if (
                 isinstance(maybe_import_from, nodes.ImportFrom)
                 and maybe_import_from.modname == "typing"
@@ -2295,3 +2315,20 @@ def not_condition_as_string(
         )
         msg = f"{lhs} {get_inverse_comparator(ops)} {rhs}"
     return msg
+
+
+def clear_lru_caches() -> None:
+    """Clear caches holding references to AST nodes."""
+    # pylint: disable-next=import-outside-toplevel
+    from pylint.checkers.variables import overridden_method
+
+    caches_holding_node_references: list[_lru_cache_wrapper[Any]] = [
+        in_for_else_branch,
+        infer_all,
+        is_overload_stub,
+        overridden_method,
+        unimplemented_abstract_methods,
+        safe_infer,
+    ]
+    for lru in caches_holding_node_references:
+        lru.cache_clear()
