@@ -2,26 +2,20 @@
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 # Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
-import collections
+from __future__ import annotations
+
 import functools
 import warnings
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    DefaultDict,
-    Iterable,
-    List,
-    Sequence,
-    Tuple,
-    Union,
-)
+from collections import defaultdict
+from collections.abc import Iterable, Sequence
+from typing import TYPE_CHECKING, Any
 
 import dill
 
 from pylint import reporters
-from pylint.lint.utils import _patch_sys_path
+from pylint.lint.utils import _augment_sys_path
 from pylint.message import Message
-from pylint.typing import FileItem, MessageLocationTuple
+from pylint.typing import FileItem
 from pylint.utils import LinterStats, merge_stats
 
 try:
@@ -29,63 +23,64 @@ try:
 except ImportError:
     multiprocessing = None  # type: ignore[assignment]
 
+try:
+    from concurrent.futures import ProcessPoolExecutor
+except ImportError:
+    ProcessPoolExecutor = None  # type: ignore[assignment,misc]
+
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
-# PyLinter object used by worker processes when checking files using multiprocessing
+# PyLinter object used by worker processes when checking files using parallel mode
 # should only be used by the worker processes
-_worker_linter = None
-
-
-def _get_new_args(message):
-    location = (
-        message.abspath,
-        message.path,
-        message.module,
-        message.obj,
-        message.line,
-        message.column,
-    )
-    return (message.msg_id, message.symbol, location, message.msg, message.confidence)
+_worker_linter: PyLinter | None = None
 
 
 def _worker_initialize(
-    linter: bytes, arguments: Union[None, str, Sequence[str]] = None
+    linter: bytes, extra_packages_paths: Sequence[str] | None = None
 ) -> None:
-    """Function called to initialize a worker for a Process within a multiprocessing Pool.
+    """Function called to initialize a worker for a Process within a concurrent Pool.
 
     :param linter: A linter-class (PyLinter) instance pickled with dill
-    :param arguments: File or module name(s) to lint and to be added to sys.path
+    :param extra_packages_paths: Extra entries to be added to sys.path
     """
     global _worker_linter  # pylint: disable=global-statement
     _worker_linter = dill.loads(linter)
+    assert _worker_linter
 
     # On the worker process side the messages are just collected and passed back to
     # parent process as _worker_check_file function's return value
     _worker_linter.set_reporter(reporters.CollectingReporter())
     _worker_linter.open()
 
-    # Patch sys.path so that each argument is importable just like in single job mode
-    _patch_sys_path(arguments or ())
+    if extra_packages_paths:
+        _augment_sys_path(extra_packages_paths)
 
 
 def _worker_check_single_file(
     file_item: FileItem,
-) -> Tuple[
-    int, Any, str, Any, List[Tuple[Any, ...]], LinterStats, Any, DefaultDict[Any, List]
+) -> tuple[
+    int,
+    # TODO: 3.0: Make this only str after deprecation has been removed
+    str | None,
+    str,
+    str | None,
+    list[Message],
+    LinterStats,
+    int,
+    defaultdict[str, list[Any]],
 ]:
     if not _worker_linter:
-        raise Exception("Worker linter not yet initialised")
+        raise RuntimeError("Worker linter not yet initialised")
     _worker_linter.open()
     _worker_linter.check_single_file_item(file_item)
-    mapreduce_data = collections.defaultdict(list)
+    mapreduce_data = defaultdict(list)
     for checker in _worker_linter.get_checkers():
-        try:
-            data = checker.get_map_data()
-        except AttributeError:
-            continue
-        mapreduce_data[checker.name].append(data)
-    msgs = [_get_new_args(m) for m in _worker_linter.reporter.messages]
+        data = checker.get_map_data()
+        if data is not None:
+            mapreduce_data[checker.name].append(data)
+    msgs = _worker_linter.reporter.messages
+    assert isinstance(_worker_linter.reporter, reporters.CollectingReporter)
     _worker_linter.reporter.reset()
     if _worker_linter.current_name is None:
         warnings.warn(
@@ -107,13 +102,16 @@ def _worker_check_single_file(
     )
 
 
-def _merge_mapreduce_data(linter, all_mapreduce_data):
+def _merge_mapreduce_data(
+    linter: PyLinter,
+    all_mapreduce_data: defaultdict[int, list[defaultdict[str, list[Any]]]],
+) -> None:
     """Merges map/reduce data across workers, invoking relevant APIs on checkers."""
     # First collate the data and prepare it, so we can send it to the checkers for
     # validation. The intent here is to collect all the mapreduce data for all checker-
     # runs across processes - that will then be passed to a static method on the
     # checkers to be reduced and further processed.
-    collated_map_reduce_data = collections.defaultdict(list)
+    collated_map_reduce_data: defaultdict[str, list[Any]] = defaultdict(list)
     for linter_data in all_mapreduce_data.values():
         for run_data in linter_data:
             for checker_name, data in run_data.items():
@@ -129,27 +127,30 @@ def _merge_mapreduce_data(linter, all_mapreduce_data):
 
 
 def check_parallel(
-    linter: "PyLinter",
+    linter: PyLinter,
     jobs: int,
     files: Iterable[FileItem],
-    arguments: Union[None, str, Sequence[str]] = None,
+    extra_packages_paths: Sequence[str] | None = None,
 ) -> None:
     """Use the given linter to lint the files with given amount of workers (jobs).
 
     This splits the work filestream-by-filestream. If you need to do work across
-    multiple files, as in the similarity-checker, then inherit from MapReduceMixin and
-    implement the map/reduce mixin functionality.
+    multiple files, as in the similarity-checker, then implement the map/reduce mixin functionality.
     """
     # The linter is inherited by all the pool's workers, i.e. the linter
     # is identical to the linter object here. This is required so that
     # a custom PyLinter object can be used.
-    initializer = functools.partial(_worker_initialize, arguments=arguments)
-    with multiprocessing.Pool(
-        jobs, initializer=initializer, initargs=[dill.dumps(linter)]
-    ) as pool:
+    initializer = functools.partial(
+        _worker_initialize, extra_packages_paths=extra_packages_paths
+    )
+    with ProcessPoolExecutor(
+        max_workers=jobs, initializer=initializer, initargs=(dill.dumps(linter),)
+    ) as executor:
         linter.open()
         all_stats = []
-        all_mapreduce_data = collections.defaultdict(list)
+        all_mapreduce_data: defaultdict[
+            int, list[defaultdict[str, list[Any]]]
+        ] = defaultdict(list)
 
         # Maps each file to be worked on by a single _worker_check_single_file() call,
         # collecting any map/reduce data by checker module so that we can 'reduce' it
@@ -163,13 +164,11 @@ def check_parallel(
             stats,
             msg_status,
             mapreduce_data,
-        ) in pool.imap_unordered(_worker_check_single_file, files):
+        ) in executor.map(_worker_check_single_file, files):
             linter.file_state.base_name = base_name
+            linter.file_state._is_base_filestate = False
             linter.set_current_module(module, file_path)
             for msg in messages:
-                msg = Message(
-                    msg[0], msg[1], MessageLocationTuple(*msg[2]), msg[3], msg[4]
-                )
                 linter.reporter.handle_message(msg)
             all_stats.append(stats)
             all_mapreduce_data[worker_idx].append(mapreduce_data)
@@ -177,8 +176,3 @@ def check_parallel(
 
     _merge_mapreduce_data(linter, all_mapreduce_data)
     linter.stats = merge_stats([linter.stats] + all_stats)
-
-    # Insert stats data to local checkers.
-    for checker in linter.get_checkers():
-        if checker is not linter:
-            checker.stats = linter.stats
